/* tslint:disable:max-line-length */
import {fakeAsync, TestBed, tick} from '@angular/core/testing';
import {AppComponent} from './app.component';
import {DataSourceService} from './services/data-source.service';
import {MatDialog} from '@angular/material/dialog';
import {of} from 'rxjs';
import {HttpClientTestingModule} from '@angular/common/http/testing';
import {UserContextService} from './services/user-context.service';
import {NamePipe} from './patient-information/name.pipe';
import {CprPipe} from './pipes/cpr.pipe';
import {AppModule} from './app.module';
import {AngularMaterialModule} from './modules/angular-material.module';
import {MatMenu} from '@angular/material/menu';

describe('AppComponent', () => {

  beforeEach(async () => {
    const dataSourceService = {
      dummyDataCards$: of([{
        identifier: '1',
        episodeOfCareIdentifier: '2',
        recordTarget: {
          identifier: '1008821234',
          name: {
            firstNames: ['Peter'],
            middleNames: [],
            lastName: 'Parker'
          }
        },
        personalDataSection: {
          cpr: '1008821234',
          name: {
            firstNames: ['Peter'],
            middleNames: [],
            lastName: 'Parker'
          }
        },
        socialHistorySection: {
          partner: {
            translationLanguage: 'something',
            nationality: 'whetever',
            needsTranslation: 'yes'
          }
        },
        expectedDateOfDeliverySection: {
          expectedDateOfDeliveryFromLastPeriod: {}
        }
      }]),
      isLoading$: of(false)
    };
    const userContextService = {
      selectedRole$: of({authorizationCode: 'LK34Q', educationCode: '9495', educationType: 'Bandagist'}),
      userContext$: of({commonName: 'Lars Larsen', organizationName: 'Company A/S', eligibleRoles: [{authorizationCode: 'J0184', educationCode: '7170', educationType: 'Læge'}, {authorizationCode: 'LK34Q', educationCode: '9495', educationType: 'Bandagist'}]}),
      eligibleRoles$: of({authorizationCode: 'LK34Q', educationCode: '9495', educationType: 'Bandagist'}),
      contextIsInitialized$: of(true),
      selectedOrganizationSor$: of('sorId')
    };
    await TestBed.configureTestingModule({
      declarations: [ AppComponent, NamePipe, CprPipe ],
      imports: [
        HttpClientTestingModule,
        AppModule,
      ],
      providers: [
        {provide: DataSourceService, useValue: dataSourceService},
        {provide: MatDialog, useValue: {}},
        {provide: UserContextService, useValue: userContextService}
      ]
    })
      .compileComponents();
  });

  it('should create the app', () => {
    const fixture = TestBed.createComponent(AppComponent);
    const app = fixture.componentInstance;
    expect(app).toBeTruthy();
  });

  it(`should have as title 'maternaty-web'`, () => {
    const fixture = TestBed.createComponent(AppComponent);
    const app = fixture.componentInstance;
    expect(app.title).toEqual('eGraviditet');
  });

  it('should render title', fakeAsync(() => {
    const fixture = TestBed.createComponent(AppComponent);
    fixture.detectChanges();
    const compiled = fixture.nativeElement;
    tick(200);
    expect(compiled.querySelector('.patientContext > .patientName').textContent).toContain('Peter Parker');
  }));
});
