import {ChangeDetectionStrategy, Component, ElementRef, HostListener, OnDestroy, ViewChild} from '@angular/core';
import {of, Subscription} from 'rxjs';
import {DataSourceService} from './services/data-source.service';
import {FeedbackComponent} from './feedback/feedback.component';
import {UserContextService} from './services/user-context.service';
import {RoleSelectorComponent} from './role-selector/role-selector.component';
import {MatIconRegistry} from '@angular/material/icon';
import {DomSanitizer} from '@angular/platform-browser';
import {DataCard} from 'facade-api';
import {DialogService} from './modals/dialog/dialog.service';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss'],
})
export class AppComponent implements OnDestroy {
  title = 'eGraviditet';
  dataCard: DataCard | undefined;
  private dataCardSubscription: Subscription;

  @ViewChild('sidebar') sidebar?: ElementRef<HTMLElement>;

  constructor(
    public dataSourceService: DataSourceService,
    public userContextService: UserContextService,
    public dialogService: DialogService,
    private matIconRegistry: MatIconRegistry,
    private domSanitizer: DomSanitizer
  ) {
    this.registerIcons();
    this.userContextService.userContext$.pipe(
    );
    // load data immediately'
    this.dataCardSubscription = this.dataSourceService.dummyDataCards$.subscribe((cards) => {
      this.dataCard = cards[0];
    });
  }

  private registerIcons(): void {
    this.matIconRegistry.addSvgIcon('ic-edit',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_edit.svg'));
    this.matIconRegistry.addSvgIcon('ic-view',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_view-faded.svg'));
    this.matIconRegistry.addSvgIcon('ic-edit-highlight',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_edit_highlighted.svg'));
    this.matIconRegistry.addSvgIcon('ic-trash',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_trash.svg'));
    this.matIconRegistry.addSvgIcon('ic-calendar',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_calendar.svg'));
    this.matIconRegistry.addSvgIcon('ic-more',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_more.svg'));
    this.matIconRegistry.addSvgIcon('ic-info',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_info.svg'));
    this.matIconRegistry.addSvgIcon('ic-add',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_add.svg'));
    this.matIconRegistry.addSvgIcon('ic-close',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_close-large.svg'));
    this.matIconRegistry.addSvgIcon('ic-care-plan',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_fagperson-mand.svg'));
    this.matIconRegistry.addSvgIcon('ic-overview',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_overblik.svg'));
    this.matIconRegistry.addSvgIcon('ic-add-colored',
      this.domSanitizer.bypassSecurityTrustResourceUrl('../assets/img/ic_add-colored.svg'));
  }

  openChangeRoleDialog(): void {
   this.dialogService.show(RoleSelectorComponent, {
      width: 'fit-content',
    });

  }

  @HostListener('window:scroll')
  public allowYScrollFrame(): void {
    const supportPageOffset = window.pageXOffset !== undefined;
    const isCSS1Compat = ((document.compatMode || '') === 'CSS1Compat');
    const x = supportPageOffset ? window.pageXOffset : isCSS1Compat ? document.documentElement.scrollLeft : document.body.scrollLeft;
    const y = supportPageOffset ? window.pageYOffset : isCSS1Compat ? document.documentElement.scrollTop : document.body.scrollTop;
    if (this.sidebar?.nativeElement) {
      this.sidebar.nativeElement.style.left = `${-x}px`;
      if (y <= 72) {
        this.sidebar.nativeElement.style.top = `${72 - y}px`;
      }
    }
  }

  ngOnDestroy(): void {
    this.dataCardSubscription.unsubscribe();
  }

  openFeedbackDialog(): void {
    this.dialogService.show(FeedbackComponent);
  }

  public swapEncounter(): void {
    console.log('Swapping encounter..');
  }

  public finishEncounter(): void {
    console.log('Finish encounter..');
  }
}
