import {ComponentFixture, fakeAsync, TestBed} from '@angular/core/testing';

import {GeneralInformationBarComponent} from './general-information-bar.component';
import {AppModule} from '../app.module';
import {of} from 'rxjs';
import {DataSourceService} from '../services/data-source.service';
import {DataCardResponse} from 'facade-api';
import {OverallAssessmentSectionPrenatalCareAssessmentNS} from '../../../projects/facade-api';
import {YesNoEnum} from '../../../projects/facade-api';
import {DataFieldComponent} from '../activities/data-field/data-field.component';

describe('GeneralInformationBarComponent', () => {
  let component: GeneralInformationBarComponent;
  let fixture: ComponentFixture<GeneralInformationBarComponent>;

  beforeEach(async () => {
    const spy = {
      dummyDataCards$: of([{
        episodeOfCareIdentifier: '1',
        recordTarget: {
          identifier: '1111111111',
          name: {
            firstNames: ['Peter'],
            middleNames: ['The'],
            lastName: 'Meter',
          }
        },
        chronicalDiseasesSection: {
          circulatorySystem: YesNoEnum.YES,
          respitorySystem: YesNoEnum.YES,
          thyroid: YesNoEnum.NO,
          diabetes: YesNoEnum.YES,
        },
        overallAssessmentSection: {
          prenatalCareAssessment: {
            assessment: 'this aint good',
            numberOfFetuses: 1,
            careLevel: OverallAssessmentSectionPrenatalCareAssessmentNS.CareLevelEnum.Basic
          }
        }
      } as unknown as DataCardResponse])
    };
    await TestBed.configureTestingModule({
      declarations: [ GeneralInformationBarComponent, DataFieldComponent],
      imports: [AppModule],
      providers: [
        {provide: DataSourceService, useValue: spy}
      ]
    })
    .compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(GeneralInformationBarComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('computes care-level display-text on init', () => {
    expect(component.careLevel).toEqual('1');
  });

  it('computes care-level display-text correctly', () => {
    const componentWithExposedMethod = component as unknown as
      {computeCareLevel(carelevel?: OverallAssessmentSectionPrenatalCareAssessmentNS.CareLevelEnum): string};
    expect(componentWithExposedMethod.computeCareLevel(undefined)).toEqual('?');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessmentNS.CareLevelEnum.Basic)
    ).toEqual('1');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessmentNS.CareLevelEnum.Extended)
    ).toEqual('2');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessmentNS.CareLevelEnum.SpecialistMultidisciplinaryTeam
    )).toEqual('3');
    expect(componentWithExposedMethod.computeCareLevel(
      OverallAssessmentSectionPrenatalCareAssessmentNS.CareLevelEnum.HighRiskPregnancyCare
    )).toEqual('4');
  });

  it('computes special conditions display-text', fakeAsync(() => {
    expect(component.chronicDiseases).toEqual('Nej');
  }));

  it('it enters scroll-mode when window is scrolled', (done) => {
    spyOn(component.headerContainer?.nativeElement, 'getBoundingClientRect').and.returnValue({top: -200});
    expect(component.headerInScrollMode).toBeFalse();
    window.dispatchEvent(new Event('scroll'));
    fixture.detectChanges();
    fixture.whenStable().then(() => {
      expect(component.headerInScrollMode).toBeTrue();
      done();
    });
  });

  it('it leaves scroll-mode when window is scrolled back', (done) => {
    // First let's scroll down
    const returnValue = {top: -200};
    spyOn(component.headerContainer?.nativeElement, 'getBoundingClientRect').and.returnValue(returnValue);
    expect(component.headerInScrollMode).toBeFalse();
    window.dispatchEvent(new Event('scroll'));
    fixture.detectChanges();

    // Cool... Now let's scroll back up
    returnValue.top = 10;
    window.dispatchEvent(new Event('scroll'));
    fixture.detectChanges();

    // Now we'd expect to no longer be in scroll mode
    fixture.whenStable().then(() => {
      expect(component.headerInScrollMode).toBeFalse();
      done();
    });
  });
});
