import {AfterViewInit, Directive, ElementRef, Input} from '@angular/core';
import {ActivatedRoute, Params, Router} from '@angular/router';
import {WindowService} from './services/window.service';
import {timer} from "rxjs";

@Directive({
  selector: '[appHighlightOnNavigation]'
})
export class HighlightOnNavigationDirective implements AfterViewInit{
  @Input('appHighlightOnNavigation') id: string|undefined;

  constructor(private element: ElementRef, private activeRoute: ActivatedRoute, private router: Router,) {}

  ngAfterViewInit(): void {
    this.activeRoute.queryParamMap.subscribe(params => {
      if (params.has('highlight')) {
        const highlightId = params.get('highlight');
        if (highlightId === this.id) {
          this.removeHighlightParam().then(() => {
            this.element.nativeElement.scrollIntoView({behavior: 'smooth', block: 'center'});
            this.element.nativeElement.classList.add('highlighted');
            const blinker = timer(0, 800).subscribe(() => {
              this.element.nativeElement.classList.remove('hover');
              setTimeout(() => this.element.nativeElement.classList.add('hover'), 300 );
            });
            setTimeout(() => {
              blinker.unsubscribe();
              this.element.nativeElement.classList.add('hover');
            },  1600);
          });
        }
      }
    });
  }

  removeHighlightParam(): Promise<void> {
    const queryParams: Params = { highlight: undefined};
    return this.router.navigate(
      [],
      {
        relativeTo: this.activeRoute,
        queryParams,
        queryParamsHandling: 'merge'
      }).then(() => undefined);
  }

}
