import {ComponentFixture, fakeAsync, TestBed, tick} from '@angular/core/testing';

import { LoadingComponent } from './loading.component';
import {ActiveRequests} from '../services/active-requests.service';
import {Subject} from 'rxjs';
import {AngularMaterialModule} from '../modules/angular-material.module';

describe('LoadingComponent', () => {
  let component: LoadingComponent;
  let fixture: ComponentFixture<LoadingComponent>;
  let currentRequests: Subject<number>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [ LoadingComponent ],
      imports: [AngularMaterialModule],
      providers: [
        {provide: ActiveRequests, useValue: {countBlockingRequests: () => currentRequests.asObservable() }},
      ]
    })
    .compileComponents();
  });

  beforeEach(() => {
    currentRequests = new Subject();
    fixture = TestBed.createComponent(LoadingComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('shows spinner when requests are pending', fakeAsync(() => {
    currentRequests.next(1);
    fixture.detectChanges();
    tick();
    expect(document.getElementsByClassName('mask').length).toBe(1);
  }));

  it('hides spinner when no requests are active', fakeAsync(() => {
    currentRequests.next(3);
    fixture.detectChanges();
    tick();
    expect(document.getElementsByClassName('mask').length).toBe(1);
    currentRequests.next(0);
    tick();
    expect(document.getElementsByClassName('mask').length).toBe(0);
  }));

  it('disables keyboard input when loading mask is displayed', fakeAsync(() => {
    currentRequests.next(3);
    fixture.detectChanges();
    tick();
    const event = new KeyboardEvent('keyDown');
    const preventDefault = spyOn(event, 'preventDefault').and.callThrough();
    component.disableKeys(event);
    expect(preventDefault).toHaveBeenCalled();
  }));
});
