import {ChangeDetectorRef, Component, HostListener, Input, OnInit} from '@angular/core';
import {ActiveRequests} from '../services/active-requests.service';

@Component({
  selector: 'app-loading',
  templateUrl: './loading.component.html',
  styleUrls: ['./loading.component.scss']
})
export class LoadingComponent implements OnInit {
  @Input() diameter = 100;
  public isLoading = 0;
  constructor(private activeRequests: ActiveRequests, private changeDetector: ChangeDetectorRef) {}

  ngOnInit(): void {
    this.activeRequests.countBlockingRequests().subscribe(
      (count) => {
        this.isLoading = count;
        if (count === 0) {
          this.changeDetector.detectChanges();
        }
      }
    );
  }

  @HostListener('document:keydown', ['$event'])
  public disableKeys(event: KeyboardEvent): void {
    if (this.isLoading) {
      // We don't want users to be able to click around while loading - not even if they're tricky enough to try to tab around
      event.returnValue = false;
      event.preventDefault();
    }
  }
}
