import {Component, EventEmitter, Input, OnChanges, Output, SimpleChanges} from '@angular/core';
import {CreateRegularObservationsRequest, CreateUltrasoundObservationsRequest, DataCard} from 'facade-api';
import {ControlContainer, NgForm} from '@angular/forms';

@Component({
  selector: 'app-edit-ultrasound',
  templateUrl: './edit-ultrasound.component.html',
  styleUrls: ['./edit-ultrasound.component.scss'],
  viewProviders: [ { provide: ControlContainer, useExisting: NgForm } ]
})
export class EditUltrasoundComponent implements OnChanges {
  @Input()  observationData: CreateUltrasoundObservationsRequest|undefined;
  @Input()  dataCard: DataCard|undefined;
  public trimesterScan?: 'trimester1' | 'trimester2' | 'other';

  constructor() { }

  ngOnChanges(changes: SimpleChanges): void {
    if (changes.dataCard) {
      this.handleFetusCountUpdate(this.dataCard?.overallAssessmentSection?.prenatalCareAssessment?.numberOfFetuses || 0);
    }
  }

  public handleFetusCountUpdate(fetusCount: number): void {
    if (this.observationData) {
      if (!fetusCount || fetusCount === this.observationData.fetuses.length) {
        return; // If the user is claiming to have 0 feti something is wrong... We'll hold off on deleting stuff
      }
      if (fetusCount < this.observationData.fetuses.length) {
        this.observationData.fetuses = this.observationData.fetuses.slice(0, fetusCount);
      }
      if (fetusCount > this.observationData.fetuses.length) {
        for (let neededFeti = fetusCount - this.observationData.fetuses.length; neededFeti > 0; neededFeti--) {
          this.observationData.fetuses.push(
            {id: `Foster ${this.observationData.fetuses.length + 1}`}
          );
        }
      }
    }
  }
}
