import {Component, OnInit, ViewChild} from '@angular/core';
import {DataCard, DataCardRequest, Uuidv4} from 'facade-api';
import {finalize} from 'rxjs/operators';
import {NgForm} from '@angular/forms';
import {DataSourceService} from '../../services/data-source.service';
import {FormComponent} from '../../confirm-navigation-if-dirty.framework';

@Component({
  selector: 'app-measurements-tab',
  templateUrl: './measurements-tab.component.html',
  styleUrls: ['./measurements-tab.component.scss'],
})
export class MeasurementsTabComponent extends FormComponent implements OnInit{
  public dataCard: DataCard | undefined;
  public disableSaveButton = false;
  private identifier: Uuidv4 = '';
  public viewActivityDialog: {isOpen: boolean; activityId?: string} = {isOpen: false};
  public editUltrasoundDialog: {isOpen: boolean; observationType: 'regular' | 'ultrasound' } = {isOpen: false, observationType: 'regular'};

  @ViewChild('form', {static: true}) form: NgForm|undefined;

  constructor(private dataSourceService: DataSourceService) { super(); (window as any).form = this.form; }

  ngOnInit(): void {
    this.dataSourceService.dummyDataCards$.subscribe((cards) => {
        const {identifier, episodeOfCareIdentifier, ...dataCard} = cards[0];
        this.identifier = episodeOfCareIdentifier || '';
        this.dataCard = dataCard;
    });
  }

  public save(): void {
    if (this.form?.valid) {
      this.disableSaveButton = true;
      this.dataSourceService.updateDataCard(this.identifier, this.dataCard as DataCardRequest)
        .pipe(finalize(() => this.disableSaveButton = false))
        .subscribe(() => {
          this.dataSourceService.refresh();
        });
    }
  }
}
