import {Component, forwardRef, OnInit, ViewChild} from '@angular/core';
import {ControlValueAccessor, NG_VALUE_ACCESSOR} from '@angular/forms';
import {ModalComponent} from '../../modals/modal/modal.component';
import {DataSourceService} from '../../services/data-source.service';
import {Activity} from 'facade-api';

export const TIE_TO_ACTIVITY_CONTROL_VALUE_ACCESSOR: any = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: forwardRef(() => TieToActivityModalComponent),
  multi: true
};

@Component({
  selector: 'app-tie-to-activity-modal',
  templateUrl: './tie-to-activity-modal.component.html',
  styleUrls: ['./tie-to-activity-modal.component.scss'],
  providers: [TIE_TO_ACTIVITY_CONTROL_VALUE_ACCESSOR],
  host: {
    '(mouseenter)': 'onMouseEnter()',
    '(mouseleave)': 'onMouseLeave()'
  }
})
export class TieToActivityModalComponent implements OnInit, ControlValueAccessor {
  @ViewChild('modal') public modalComponent: ModalComponent | undefined;
  public innerModel?: Activity = undefined;
  public currentValue: string | undefined = '';
  public displayText = '';
  public disabled = false;
  public hover = false;
  public activities: Activity[] = [];

  private onChangeCallback: (newValue?: string) => any = () => {};
  private onTouchedCallback: () => any = () => {};

  constructor(private dataSourceService: DataSourceService) { }

  public ngOnInit(): void {
    this.dataSourceService.activities$.subscribe((activities) => {
      this.activities = activities;
    });
  }

  get value(): string|undefined {
    return this.innerModel?.id;
  }

  set value(value: string|undefined) {
    if (value !== this.innerModel?.id) {
      this.innerModel = this.activities.find(x => x.id === this.currentValue);
      this.onChangeCallback(value);
    }
  }

  registerOnChange(fn: any): void {
    this.onChangeCallback = fn;
  }

  registerOnTouched(fn: any): void {
    this.onTouchedCallback = fn;
  }

  setDisabledState(isDisabled: boolean): void {
    this.disabled = isDisabled;
  }

  writeValue(newValue: string): void {
    this.currentValue = newValue;
    this.value = newValue;
    this.displayText = this.getDisplayText();
  }

  onMouseEnter(): void {
    this.hover = !this.disabled;
  }

  onMouseLeave(): void {
    this.hover = false;
  }

  public handleClose(): void {
    this.modalComponent?.setVisible(false);
    this.value = this.currentValue;
  }

  public open(): void {
    this.modalComponent?.setVisible(true);
  }

  public pickActivity(): void {
    this.currentValue = this.innerModel?.id;
    this.displayText = this.getDisplayText();
    this.onChangeCallback(this.innerModel?.id);
    this.handleClose();
  }

  private getDisplayText(): string {
    return this.activities.find(x => x.id === this.currentValue)?.title || '';
  }

}
