import {Component, OnDestroy, OnInit, ViewChild} from '@angular/core';
import {DataSourceService} from '../services/data-source.service';
import {Subscription} from 'rxjs';
import {DataCard, DataCardRequest, Uuidv4} from 'facade-api';
import {NgForm} from '@angular/forms';

@Component({
  selector: 'app-patient-information',
  templateUrl: './patient-information.component.html',
  styleUrls: ['./patient-information.component.scss']
})
export class PatientInformationComponent implements OnInit, OnDestroy {
  @ViewChild('form', {static: true}) form: NgForm|undefined;
  public dataCard: DataCard|undefined;
  private identifier: Uuidv4 = '';
  private subscription: Subscription|undefined;
  public disableSaveButton = false;

  constructor(private dataSourceService: DataSourceService) { }

  ngOnInit(): void {
    this.subscription = this.dataSourceService.dummyDataCards$
      .subscribe((dataCards) => {
        const {identifier, episodeOfCareIdentifier, ...dataCard} = dataCards[0];
        this.identifier = episodeOfCareIdentifier || '';
        this.dataCard = dataCard;
      });
  }

  ngOnDestroy(): void {
    this.subscription?.unsubscribe();
  }

  public displayRelation(relation: string): string {
    switch (relation) {
      case 'uspec_paaroerende':
        return 'Ukendt';
      case 'ingen_relationer':
        return 'Ingen relation';
      case 'barn':
        return 'Barn';
      case 'mor':
        return 'Mor';
      case 'far':
        return 'Far';
      case 'forælder':
        return 'Forælder';
      case 'søskende':
        return 'Søskende';
      case 'aegtefaelle':
        return 'Ægtefælle';
      case 'barnebarn':
        return 'Barnebarn';
      case 'svigerbarn':
        return 'Svigerbarn';
      case 'øvrig_familie':
        return 'Øvrig familie';
      case 'nabo':
        return 'Nabo';
      case 'samboende':
        return 'Samboende';
      case 'registreret_partner':
        return 'Registreret partner';
      case 'anden':
        return 'Anden';
      case 'søn':
        return 'Søn';
      case 'datter':
        return 'Datter';
      default:
        return '?';
    }
  }

  public save(): void {
    this.disableSaveButton = true;
    this.dataSourceService.updateDataCard(this.identifier, this.dataCard as DataCardRequest)
      .subscribe(() => {
        this.disableSaveButton = false;
        this.dataSourceService.refresh();
      });
  }
}
