import {Component, forwardRef} from '@angular/core';
import {ControlContainer, ControlValueAccessor, NG_VALUE_ACCESSOR, NgForm} from '@angular/forms';
import {DataCard} from 'facade-api';
import deepEqual from 'deep-equal';


export const APP_MEDICAL_HISTORY_CONTROL_VALUE_ACCESSOR: any = {
  provide: NG_VALUE_ACCESSOR,
  useExisting: forwardRef(() => MedicalHistoryComponent),
  multi: true
};


@Component({
  selector: 'app-medical-history',
  templateUrl: './medical-history.component.html',
  styleUrls: ['./medical-history.component.scss'],
  providers: [APP_MEDICAL_HISTORY_CONTROL_VALUE_ACCESSOR],
  viewProviders: [ { provide: ControlContainer, useExisting: NgForm } ]

})
export class MedicalHistoryComponent implements ControlValueAccessor  {
  public yes = true;
  public no = false;

  private innerModel: DataCard | undefined;
  private dirtyAble = false;
  private onChangeCallback: (newValue: DataCard|undefined) => any = () => {};
  private onTouchedCallback: () => any = () => {};

  constructor() { }

  get value(): DataCard|undefined {
    return this.innerModel;
  }

  set value(value: DataCard|undefined) {
    if (!deepEqual(value, this.innerModel)) {
      this.innerModel = value;
      if (this.dirtyAble) {
        this.onChangeCallback(value);
      }
      if (!this.dirtyAble && this.innerModel) { // We don't want to mark the field as dirty while data gets initialized
        this.dirtyAble = true;
      }
    }
  }

  registerOnChange(fn: any): void {
    this.onChangeCallback = fn;
  }

  registerOnTouched(fn: any): void {
    this.onTouchedCallback = fn;
  }

  writeValue(newValue: DataCard): void {
    this.value = newValue;
  }

  public computeBirthDate(): Date {
    return new Date();
  }

}
