import {Injectable} from '@angular/core';
import {
  HttpErrorResponse,
  HttpEvent,
  HttpHandler,
  HttpInterceptor,
  HttpRequest,
  HttpResponse
} from '@angular/common/http';
import {Observable} from 'rxjs';
import {catchError, finalize, map} from 'rxjs/operators';
import {handleError} from './errorHandling';
import {JsonTransformerUtil} from './json-transformer.util';
import {ActiveRequests} from '../app/services/active-requests.service';

@Injectable()
export class HttpRequestInterceptor implements HttpInterceptor {

  constructor(private activeRequests: ActiveRequests) {}

  intercept(request: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
    this.activeRequests._registerBlockingRequest();
    return next.handle(request).pipe(
      map((event: HttpEvent<any>) => {
        if (event instanceof HttpResponse) {
          const replaced = JsonTransformerUtil.transformDates(event.body);
          return event.clone({body: replaced});
        }
        return event;
      }),
      catchError((error: HttpErrorResponse) => {
        return handleError(error);
      }),
      finalize(() => {
        this.activeRequests._unregisterBlockingRequest();
      })
    );
  }

}
